Django Shortwave — django-shortwave v0.9.1 documentation

### Navigation

- index
- modules |
- next |
- django-shortwave v0.9.1 documentation »

# Django Shortwave

## Overview

`django-shortwave` provides the ability for users to create and manage custom command files for use with Shortwave.

Using the instructions found in the default commands file, users can add their own commands to a custom wave file. They can then provide the URL of their custom commands file to Shortwave and save their new bookmarklet.

From that point users can add, delete, and change their custom commands from the admin and their bookmarklet updates immediately (that’s the beauty of Shortwave).

## Really?

Yes, this application really is just a glorified, big-hammer way of creating, editing, and serving a few text files. Why? The fun. The exercise. The laziness of not wanting to manage and backup some random text files on a static server. Wanting non-technical family members to have a syntactically correct commands file, should they ever want one.

Big answers to small problems can sometimes be fun.

## Contents

- Installation
  - Requirements
  - The Package
  - The App
- Usage
  - Read Shortwave Instructions
  - Create Wave File
  - Save The Bookmarklet
- Support
  - `django-shortwave`
  - Shortwave

## Indices, etc.

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- django-shortwave v0.9.1 documentation »